==> netscape-7.1-i686-1.tgz: usr/lib/netscape/defaults/pref/mailnews-ns.js <==
/* override some prefs in mailnews.js */
pref("mailnews.start_page.url", "chrome://messenger-region/locale/region-ns.properties");
pref("messenger.throbber.url","chrome://messenger-region/locale/region-ns.properties");
pref("compose.throbber.url","chrome://messenger-region/locale/region-ns.properties");
pref("addressbook.throbber.url","chrome://messenger-region/locale/region-ns.properties");
pref("mail.absync.port",5001);
pref("mail.absync.server","mailwsg.mcom.com/_cqr/sync");
pref("mail.absync.firsttime",true);
pref("mailnews.reply_on_top", 1);
pref("mail.display_struct", false);
pref("mail.forward_message_mode", 2); // 0=default as attachment 2=forward as inline with attachments, (obsolete)1=forward as quoted
pref("mail.asksendformat.default", 3); //1=plaintext, 2=html, 3=both
pref("default_offline_support_level.imap.mail.aol.com", 0);
pref("default_supports_diskspace.imap.mail.aol.com", false);
pref("default_offline_support_level.imap.mail.netcenter.com", 10);

// for default_redirector_type, see bugscape bugs #19665 and #20069
// format is "default_redirector_type." + protocol + "." + hostname
pref("default_redirector_type.imap.mail.aol.com","aol");
pref("default_redirector_type.imap.mail.netcenter.com","netscape");
pref("default_redirector_type.smtp.smtp.aol.com","aol");
pref("default_redirector_type.smtp.smtp.netscape.net","netscape");

// override for the "aol" redirector type.
// see nsImapIncomingServer::AllowFolderConversion() for details
// see nsImapIncomingServer::HideFolderName() for details
// see nsImapIncomingServer::GetTrashFolderByRedirectorType() for details
pref("imap.aol.convertFolders",true);
pref("imap.aol.hideFolder.RECYCLE_OUT",true)
pref("imap.aol.trashFolder","RECYCLE");
pref("imap.aol.isSecureServer", false);
pref("imap.aol.canEmptyTrashOnExit", false);
pref("imap.aol.canCreateFolders", false);
pref("imap.aol.canCompactFoldersOnServer", false);
pref("imap.aol.canUndoDeleteOnServer", false);
pref("imap.aol.canSearchMessages", false);
pref("imap.aol.canFileMessages", false);
pref("imap.aol.canSearchMessages", false);
pref("imap.aol.emptyTrashOnExit", false);
pref("imap.aol.showMessagesAfterLoading",true);

pref("imap.netscape.canSearchMessages", false);
pref("imap.netscape.isSecureServer", false);

// hide hostname when prompting for password for these types
// see bugscape bugs #19993 and #20196
// format is protocol + "." + redirector_type + ".hide_hostname_for_password"
pref("imap.aol.hide_hostname_for_password",true);
pref("imap.netscape.hide_hostname_for_password",true);
pref("smtp.aol.hide_hostname_for_password",true);
pref("smtp.netscape.hide_hostname_for_password",true);

pref("mailnews.bannerad.alternateDisplay", false);
pref("mailnews.global_html_domains", "netscape.net,netscape.com,aol.com,cs.com,yahoo.com,hotmail.com,msn.com");
pref("mail.aol.unreadMailCountRegistryKeyPrefix", "America Online - ");
pref("mailnews.fakeaccount.show", true);
pref("mailnews.fakeaccount.server", "imap.mail.netcenter.com");
pref("mail.accountmanager.aol.hide_advanced_button", true);
pref("mail.accountmanager.netscape.hide_advanced_button", true);
/* ns tree specific prefs */
pref("browser.toolbars.showbutton.mailPT", true);

==> netscape-7.2-i686-1.tgz: usr/lib/netscape/defaults/pref/mailnews-ns.js <==
/* override some prefs in mailnews.js */
pref("mailnews.start_page.url", "chrome://messenger-region/locale/region-ns.properties");
pref("messenger.throbber.url","chrome://messenger-region/locale/region-ns.properties");
pref("compose.throbber.url","chrome://messenger-region/locale/region-ns.properties");
pref("addressbook.throbber.url","chrome://messenger-region/locale/region-ns.properties");
pref("mail.absync.port",5001);
pref("mail.absync.server","mailwsg.mcom.com/_cqr/sync");
pref("mail.absync.firsttime",true);
pref("mailnews.reply_on_top", 1);
pref("mail.display_struct", false);
pref("mail.forward_message_mode", 2); // 0=default as attachment 2=forward as inline with attachments, (obsolete)1=forward as quoted
pref("mail.asksendformat.default", 3); //1=plaintext, 2=html, 3=both
pref("default_offline_support_level.imap.mail.aol.com", 0);
pref("default_supports_diskspace.imap.mail.aol.com", false);
pref("default_offline_support_level.imap.mail.netcenter.com", 10);

// for default_redirector_type, see bugscape bugs #19665 and #20069
// format is "default_redirector_type." + protocol + "." + hostname
pref("default_redirector_type.imap.mail.aol.com","aol");
pref("default_redirector_type.imap.mail.netcenter.com","netscape");
pref("default_redirector_type.smtp.smtp.aol.com","aol");
pref("default_redirector_type.smtp.smtp.netscape.net","netscape");

// override for the "aol" redirector type.
// see nsImapIncomingServer::AllowFolderConversion() for details
// see nsImapIncomingServer::HideFolderName() for details
// see nsImapIncomingServer::GetTrashFolderByRedirectorType() for details
pref("imap.aol.convertFolders",true);
pref("imap.aol.hideFolder.RECYCLE_OUT",true);
pref("imap.aol.trashFolder","RECYCLE");
pref("imap.aol.isSecureServer", false);
pref("imap.aol.canEmptyTrashOnExit", false);
pref("imap.aol.canCreateFolders", false);
pref("imap.aol.canCompactFoldersOnServer", false);
pref("imap.aol.canUndoDeleteOnServer", false);
pref("imap.aol.canSearchMessages", false);
pref("imap.aol.canFileMessages", false);
pref("imap.aol.canSearchMessages", false);
pref("imap.aol.emptyTrashOnExit", false);
pref("imap.aol.showMessagesAfterLoading",true);

pref("imap.netscape.canSearchMessages", false);
pref("imap.netscape.isSecureServer", false);

// hide hostname when prompting for password for these types
// see bugscape bugs #19993 and #20196
// format is protocol + "." + redirector_type + ".hide_hostname_for_password"
pref("imap.aol.hide_hostname_for_password",true);
pref("imap.netscape.hide_hostname_for_password",true);
pref("smtp.aol.hide_hostname_for_password",true);
pref("smtp.netscape.hide_hostname_for_password",true);

pref("mailnews.bannerad.alternateDisplay", false);
pref("mailnews.global_html_domains", "netscape.net,netscape.com,aol.com,cs.com,yahoo.com,hotmail.com,msn.com");
pref("mail.aol.unreadMailCountRegistryKeyPrefix", "America Online - ");
pref("mailnews.fakeaccount.show", true);
pref("mailnews.fakeaccount.server", "imap.mail.netcenter.com");
pref("mail.accountmanager.aol.hide_advanced_button", true);
pref("mail.accountmanager.netscape.hide_advanced_button", true);
/* ns tree specific prefs */
pref("browser.toolbars.showbutton.mailPT", false);

// default to both, like AOL 9 / OE 6
// see http://partner-projects.mozilla.org/show_bug.cgi?id=243
// for more details
pref("mail.default_html_action", 3); // 0=ask, 1=plain, 2=html, 3=both
